@@ -19,7 +19,7 @@ __date__ = "Jul 16, 2020"
 
 
 import copy
-from typing import Callable, Iterable
+from typing import Callable, Iterable, List
 
 import numpy as np
 import h5py
@@ -542,6 +542,15 @@ class FlattenedStorage(HasHDF):
             return None
         return {"shape": a.shape[1:], "dtype": a.dtype, "per": per}
 
+    def list_arrays(self) -> List[str]:
+        """
+        Return a list of names of arrays inside the storage.
+
+        Returns:
+            list of str: array names
+        """
+        return list(self._per_chunk_arrays) + list(self._per_element_arrays)
+
     def sample(
         self, selector: Callable[["FlattenedStorage", int], bool]
     ) -> "FlattenedStorage":
@@ -713,7 +722,7 @@ class FlattenedStorage(HasHDF):
         if new_elements > self._num_elements_alloc:
             self._resize_elements(max(new_elements, self._num_elements_alloc * 2))
         if self.current_chunk_index + 1 > self._num_chunks_alloc:
-            self._resize_chunks(self._num_chunks_alloc * 2)
+            self._resize_chunks(max(1, self._num_chunks_alloc * 2))
 
         if new_elements > self.num_elements:
             self.num_elements = new_elements
