@@ -147,7 +147,7 @@ class HasHDF(ABC):
     __hdf_version__ = "0.1.0"
 
     @abstractmethod
-    def _from_hdf(self, hdf: ProjectHDFio, version: str=None):
+    def _from_hdf(self, hdf: ProjectHDFio, version: str = None):
         pass
 
     @abstractmethod
@@ -178,7 +178,7 @@ class HasHDF(ABC):
             hdf["VERSION"] = self.__version__
         hdf["HDF_VERSION"] = self.__hdf_version__
 
-    def from_hdf(self, hdf: ProjectHDFio, group_name: str=None):
+    def from_hdf(self, hdf: ProjectHDFio, group_name: str = None):
         """
         Read object to HDF.
 
@@ -188,12 +188,14 @@ class HasHDF(ABC):
             hdf (:class:`.ProjectHDFio`): HDF group to read from
             group_name (str, optional): name of subgroup
         """
-        group_name = group_name if group_name is not None else self._get_hdf_group_name()
+        group_name = (
+            group_name if group_name is not None else self._get_hdf_group_name()
+        )
         with _WithHDF(hdf, group_name) as hdf:
             version = hdf.get("HDF_VERSION", "0.1.0")
             self._from_hdf(hdf, version=version)
 
-    def to_hdf(self, hdf: ProjectHDFio, group_name: str=None):
+    def to_hdf(self, hdf: ProjectHDFio, group_name: str = None):
         """
         Write object to HDF.
 
@@ -203,14 +205,16 @@ class HasHDF(ABC):
             hdf (:class:`.ProjectHDFio`): HDF group to write to
             group_name (str, optional): name of subgroup
         """
-        group_name = group_name if group_name is not None else self._get_hdf_group_name()
+        group_name = (
+            group_name if group_name is not None else self._get_hdf_group_name()
+        )
         with _WithHDF(hdf, group_name) as hdf:
             if len(hdf.list_dirs()) > 0 and group_name is None:
                 raise ValueError("HDF group must be empty when group_name is not set.")
             self._to_hdf(hdf)
             self._store_type_to_hdf(hdf)
 
-    def rewrite_hdf(self, hdf: ProjectHDFio, group_name: str=None):
+    def rewrite_hdf(self, hdf: ProjectHDFio, group_name: str = None):
         """
         Update the HDF representation.
 
