@@ -760,12 +760,8 @@ class GenericJob(JobCore):
                 universal_newlines=True,
                 check=True,
             ).stdout
-            with open(
-                posixpath.join(self.project_hdf5.working_directory, "error.out"),
-                mode="w",
-            ) as f_err:
-                f_err.write(out)
         except subprocess.CalledProcessError as e:
+            out = e.output
             if e.returncode in self.executable.accepted_return_codes:
                 pass
             elif not self.server.accept_crash:
@@ -785,6 +781,11 @@ class GenericJob(JobCore):
             else:
                 job_crashed = True
 
+        with open(
+            posixpath.join(self.project_hdf5.working_directory, "error.out"), mode="w"
+        ) as f_err:
+            f_err.write(out)
+
         self.set_input_to_read_only()
         self.status.collect = True
         self._logger.info(
