@@ -5,6 +5,7 @@
 Worker Class to execute calculation in an asynchronous way
 """
 import os
+import psutil
 import time
 from datetime import datetime
 from multiprocessing import Pool
@@ -126,7 +127,10 @@ class WorkerJob(PythonTemplateJob):
 
     def __init__(self, project, job_name):
         super(WorkerJob, self).__init__(project, job_name)
-        self.input.project = None
+        if not state.database.database_is_disabled:
+            self.input.project = project.path
+        else:
+            self.input.project = self.working_directory
         self.input.cores_per_job = 1
         self.input.sleep_interval = 10
         self.input.child_runtime = 0
@@ -178,6 +182,7 @@ class WorkerJob(PythonTemplateJob):
         self.project_hdf5.create_working_directory()
         log_file = os.path.join(self.working_directory, "worker.log")
         active_job_ids = []
+        process = psutil.Process(os.getpid())
         with Pool(processes=int(self.server.cores / self.cores_per_job)) as pool:
             while True:
                 # Check the database if there are more calculation to execute
@@ -235,6 +240,9 @@ class WorkerJob(PythonTemplateJob):
                         + str(len(df))
                         + " "
                         + str(len(df_sub))
+                        + " "
+                        + str(process.memory_info().rss / 1024 / 1024 / 1024)
+                        + "GB"
                         + "\n"
                     )
 
@@ -253,6 +261,7 @@ class WorkerJob(PythonTemplateJob):
         working_directory = self.working_directory
         log_file = os.path.join(working_directory, "worker.log")
         file_memory_lst = []
+        process = psutil.Process(os.getpid())
         with Pool(processes=int(self.server.cores / self.cores_per_job)) as pool:
             while True:
                 file_lst = [
@@ -279,6 +288,9 @@ class WorkerJob(PythonTemplateJob):
                         + str(len(file_memory_lst))
                         + " "
                         + str(len(file_lst))
+                        + " "
+                        + str(process.memory_info().rss / 1024 / 1024 / 1024)
+                        + "GB"
                         + "\n"
                     )
 
@@ -326,5 +338,10 @@ class WorkerJob(PythonTemplateJob):
                     )
                 log_str += "\n"
                 f.write(log_str)
+            if (
+                not state.database.database_is_disabled
+                and state.database.get_job_status(job_id=self.job_id) == "aborted"
+            ):
+                raise ValueError("The worker job was aborted.")
             time.sleep(interval_in_s)
         self.status.collect = True
