@@ -192,6 +192,31 @@ class Project(ProjectPath, HasGroups):
                 pass
         return self._data
 
+    @property
+    def size(self):
+        """
+        Get the size of the project
+        """
+        size = (
+            sum(
+                [
+                    sum([os.path.getsize(os.path.join(path, f)) for f in files])
+                    for path, dirs, files in os.walk(self.path)
+                ]
+            )
+            * pint.UnitRegistry().byte
+        )
+
+        prefix_index = math.floor(math.log2(size) / 10) - 1
+        prefix = ["Ki", "Mi", "Gi", "Ti", "Pi"]
+
+        if prefix_index < 0:
+            return size
+        elif prefix_index < 5:
+            return size.to(f"{prefix[prefix_index]}byte")
+        else:
+            return size.to(f"{prefix[-1]}byte")
+
     def copy(self):
         """
         Copy the project object - copying just the Python object but maintaining the same pyiron path
@@ -474,20 +499,15 @@ class Project(ProjectPath, HasGroups):
             job_specifier=job_specifier,
         )
 
+    @deprecate("use self.size instead.")
     def get_project_size(self):
         """
-        Get the size of the project in MegaByte.
+        Get the size of the project.
 
         Returns:
             float: project size
         """
-        folder_size = sum(
-            [
-                sum([os.path.getsize(os.path.join(path, file)) for file in files])
-                for (path, dirs, files) in os.walk(self.path)
-            ]
-        )
-        return folder_size / (1024 * 1024.0)
+        return self.size
 
     @deprecate("use maintenance.get_repository_status() instead.")
     def get_repository_status(self):
@@ -579,14 +599,22 @@ class Project(ProjectPath, HasGroups):
         """
         return [(key, self[key]) for key in self.keys()]
 
-    def update_from_remote(self, recursive=True):
+    def update_from_remote(self, recursive=True, ignore_exceptions=False):
         """
         Update jobs from the remote server
 
         Args:
             recursive (bool): search subprojects [True/False] - default=True
+            ignore_exceptions (bool): ignore eventual exceptions when retrieving jobs - default=False
+
+        Returns:
+            returns None if ignore_exceptions is False or when no error occured.
+            returns a list with job ids when errors occured, but were ignored
+
         """
-        update_from_remote(project=self, recursive=recursive)
+        return update_from_remote(
+            project=self, recursive=recursive, ignore_exceptions=ignore_exceptions
+        )
 
     def job_table(
         self,
@@ -1276,7 +1304,13 @@ class Project(ProjectPath, HasGroups):
             job=job, interval_in_s=interval_in_s, max_iterations=max_iterations
         )
 
-    def wait_for_jobs(self, interval_in_s=5, max_iterations=100, recursive=True):
+    def wait_for_jobs(
+        self,
+        interval_in_s=5,
+        max_iterations=100,
+        recursive=True,
+        ignore_exceptions=False,
+    ):
         """
         Wait for the calculation in the project to be finished
 
@@ -1284,6 +1318,7 @@ class Project(ProjectPath, HasGroups):
             interval_in_s (int): interval when the job status is queried from the database - default 5 sec.
             max_iterations (int): maximum number of iterations - default 100
             recursive (bool): search subprojects [True/False] - default=True
+            ignore_exceptions (bool): ignore eventual exceptions when retrieving jobs - default=False
 
         Raises:
             ValueError: max_iterations reached, but jobs still running
@@ -1293,6 +1328,7 @@ class Project(ProjectPath, HasGroups):
             interval_in_s=interval_in_s,
             max_iterations=max_iterations,
             recursive=recursive,
+            ignore_exceptions=ignore_exceptions,
         )
 
     @staticmethod
