@@ -32,6 +32,7 @@ Finally, :class:`Settings` converts any file paths from your OS to something pyi
 cleaning and consistency checks.
 """
 
+import ast
 import os
 from configparser import ConfigParser
 from pyiron_base.state.logger import logger
@@ -324,6 +325,7 @@ class Settings(metaclass=Singleton):
                 config[self.environment_configuration_map[k]] = v
             except KeyError:
                 pass
+        config = self._fix_boolean_var_in_config(config=config)
         return config if len(config) > 0 else None
 
     def _get_config_from_file(self) -> Union[Dict, None]:
@@ -333,7 +335,7 @@ class Settings(metaclass=Singleton):
             config_file = os.path.expanduser(os.path.join("~", ".pyiron"))
 
         if os.path.isfile(config_file):
-            parser = ConfigParser(inline_comment_prefixes=(";",))
+            parser = ConfigParser(inline_comment_prefixes=(";",), interpolation=None)
             parser.read(config_file)
             config = {}
             for sec_name, section in parser.items():
@@ -342,9 +344,9 @@ class Settings(metaclass=Singleton):
                         config[self.file_configuration_map[k.upper()]] = v
                     except KeyError:
                         pass
+            config = self._fix_boolean_var_in_config(config=config)
         else:
             config = None
-
         return config
 
     def _update_from_dict(self, config: Dict, map_: Union[None, Dict] = None) -> None:
@@ -430,5 +432,12 @@ class Settings(metaclass=Singleton):
     def publication(self):
         return publications.pyiron_publication
 
+    @staticmethod
+    def _fix_boolean_var_in_config(config):
+        for k, v in config.items():
+            if k in ["project_check_enabled", "disable_database"]:
+                config[k] = ast.literal_eval(v)
+        return config
+
 
 settings = Settings()
